
# libpyhtonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

[![Build Status](https://travis-ci.org/kjuniors2/libpyhtonpro.svg?branch=master)](https://travis-ci.org/kjuniors2/libpyhtonpro)
[![Python 3](https://pyup.io/repos/github/kjuniors2/libpyhtonpro/python-3-shield.svg)](https://pyup.io/repos/github/kjuniors2/libpyhtonpro/)
[![Updates](https://pyup.io/repos/github/kjuniors2/libpyhtonpro/shield.svg)](https://pyup.io/repos/github/kjuniors2/libpyhtonpro/)

**Para instalar:**

```console
pip install pipenv
pipenv install --dev
```

**Para conferir qualidade de código:**

```console
pipenv run flake8
```

**Tópicos a serem abordados:**
1. Git
2. Virtualenv
3. Pip
4. Mock
5. Pipenv
